<template>
	<div class="usps" v-if="filteredUsps && filteredUsps.length">
		<div class="container w-100">
			<section>
				<div class="row mx-0 mx-md-1">
					<article
						v-for="usp in filteredUsps"
						:class="colClasses"
						:key="usp.textShort"
					>
						<svg class="ok-icon">
							<use :xlink:href="`${iconUrl}${usp.icon}`"></use>
						</svg>
						<span v-if="screenSize !== 'xs'" v-html="usp.text"></span>
						<span
							v-if="screenSize === 'xs'"
							v-html="
								usp.textShort && usp.textShort.length > 0
									? usp.textShort
									: usp.text
							"
						></span>
					</article>
				</div>
			</section>
		</div>
	</div>
</template>

<script>
	module.exports = {
		name: "UspsComponent",
		store,
		data() {
			return {
				iconUrl,
			};
		},
		props: {
			index: {
				type: Number,
				default: 0,
			},
			uspIds: {
				type: Array,
				required: false,
				default: () => [],
			},
		},
		computed: {
			colClasses() {
				let classes = ["d-flex", "align-items-center"];

				switch (this.filteredUsps.length) {
					case 0:
						classes.push("d-none");
						break;
					case 1:
						classes.push("col-12 justify-content-center");
						break;
					case 2:
					case 4:
						classes.push("col-md-6");
						break;
					case 3:
						classes.push("col-lg-4 justify-content-center-md");
						break;
					case 5:
					case 6:
						classes.push("col-md-6 col-lg-4");
						break;
				}

				return classes;
			},
			filteredUsps() {
				if (this.uspIds.length === 0) {
					return this.usps.slice(
						this.index * this.numOfUsps,
						(this.index + 1) * this.numOfUsps
					);
				} else {
					return this.usps
						.filter(usp => this.uspIds.includes(usp.id))
						.slice(0, this.numOfUsps);
				}
			},
			numOfUsps() {
				if (this.uspIds.length === 0) {
					switch (this.screenSize) {
						case "xs":
							return 1;
						case "sm":
						case "md":
							return 2;
						case "lg":
						case "xl":
							return 3;
						default:
							return 0;
					}
				} else {
					switch (this.screenSize) {
						case "xs":
							return 3;
						case "sm":
						case "md":
							return 4;
						case "lg":
						case "xl":
							return 6;
						default:
							return 0;
					}
				}
			},
			screenSize() {
				return this.$store.getters.getScreenSize;
			},
			usps() {
				return this.$store.getters.usps;
			},
		},
	};
</script>
